@@ -95,8 +95,8 @@ public:
     Private(ActivitiesProtocol * parent)
         : kio(parent)
     {
-        activityManagerIface = new org::kde::ActivityManager::Activities(ACTIVITY_MANAGER_DBUS_PATH, ACTIVITY_MANAGER_DBUS_OBJECT"/Activities", QDBusConnection::sessionBus(), parent);
-        activityResourcesIface = new org::kde::ActivityManager::Resources(ACTIVITY_MANAGER_DBUS_PATH, ACTIVITY_MANAGER_DBUS_OBJECT"/Resources", QDBusConnection::sessionBus(), parent);
+        activityManager = new org::kde::ActivityManager::Activities(ACTIVITY_MANAGER_DBUS_PATH, ACTIVITY_MANAGER_DBUS_OBJECT"/Activities", QDBusConnection::sessionBus(), parent);
+        activityResources = new org::kde::ActivityManager::Resources(ACTIVITY_MANAGER_DBUS_PATH, ACTIVITY_MANAGER_DBUS_OBJECT"/Resources", QDBusConnection::sessionBus(), parent);
     }
 
     enum Path {
@@ -107,8 +107,8 @@ public:
     };
 
 //     KActivities::Consumer activities;
-    OrgKdeActivityManagerActivitiesInterface * activityManagerIface;
-    OrgKdeActivityManagerResourcesInterface * activityResourcesIface;
+    OrgKdeActivityManagerActivitiesInterface * activityManager;
+    OrgKdeActivityManagerResourcesInterface * activityResources;
     QString activityId;
     QString filename;
 
@@ -183,7 +183,7 @@ public:
                 QDate::currentDate()), false
             );
 
-        foreach (const QString & activityId, activityManagerIface->ListActivities().value()) {
+        foreach (const QString & activityId, activityManager->ListActivities().value()) {
             kio->listEntry(createFolderUDSEntry(
                     activityId,
                     KActivities::Info::name(activityId),
@@ -200,11 +200,11 @@ public:
         QString activity = activityId;
 
         if (activity == "current") {
-            activity = activityManagerIface->CurrentActivity().value();
+            activity = activityManager->CurrentActivity().value();
         }
 
         if (!activity.isEmpty()) {
-            foreach(const QString & uri, activityResourcesIface->ResourcesLinkedToActivity(activity).value()) {
+            foreach(const QString & uri, activityResources->ResourcesLinkedToActivity(activity).value()) {
                 kio->listEntry(createUDSEntryForUrl(KUrl(uri)), false);   
             }
         }
